package hdl

import (
	"applet/app/db"
	"applet/app/e"
	"applet/app/lib/validate"
	"applet/app/md"
	"applet/app/svc"
	"applet/app/utils"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/implement"
	"github.com/gin-gonic/gin"
)

// Login 登陆
// @Summary      登陆
// @Tags         登录
// @Description  登入
// @Accept       json
// @Produce      json
// @Param        req 	body      md.LoginReq          true   "用户名密码"
// @Success      200   {object}   md.LoginResponse				"token"
// @Failure      400   {object}   md.Response              	"具体错误"
// @Router       /api/login [post]
func Login(c *gin.Context) {
	var req md.LoginReq
	err := c.ShouldBindJSON(&req)
	if err != nil {
		err = validate.HandleValidateErr(err)
		err1 := err.(e.E)
		e.OutErr(c, err1.Code, err1.Error())
		return
	}
	userDb := implement.NewUserDb(db.Db)
	user, err := userDb.UserGetOneByParams(map[string]interface{}{
		"key":   "phone",
		"value": req.Phone,
	})
	if err != nil {
		e.OutErr(c, e.ERR_DB_ORM, err)
		return
	}
	if user == nil {
		e.OutErr(c, e.ERR_NO_DATA, "账号不存在！")
		return
	}
	if utils.Md5(req.PassWord) != user.Password {
		e.OutErr(c, e.ERR_INVALID_ARGS, "密码错误")
		return
	}
	//ip := utils.GetIP(c.Request)
	token, err := svc.HandleLoginToken(user)
	if err != nil {
		e.OutErr(c, e.ERR, err.Error())
		return
	}
	e.OutSuc(c, md.LoginResponse{
		Token: token,
	}, nil)
	return
}
